# Changelog

## Unreleased

## 0.7.1 (Nov 2024)
* Update release build instructions to fix versioning issue.

## 0.7.0 (Nov 2024)

* Updated dependencies to recent versions of Huggingface Transformer and Pytorch
* Improved speed of continuous integration by switching from pip to uv
* Change from black and isort to ruff
* Deprecate python 3.8 and add support for 3.11
* Add flag to train_system.py for more detailed error analysis output
* Add support for MPS-based Macs
* Updates to hierarchical model for continued training
* Improved documentation
